==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/WebColumnToggledEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnToggledEventArgsDetailDescriptionMetadata } from "./WebColumnToggledEventArgsDetailDescriptionMetadata";
import { WebColumnToggledEventArgsDescription } from "./WebColumnToggledEventArgsDescription";
/**
 * @hidden
 */
export let WebColumnToggledEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebColumnToggledEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebColumnToggledEventArgsDescriptionMetadata.a == null) {
                WebColumnToggledEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebColumnToggledEventArgsDescriptionMetadata.c(WebColumnToggledEventArgsDescriptionMetadata.a);
            }
            if (a.j(WebColumnToggledEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(WebColumnToggledEventArgsDescriptionMetadata.a);
            WebColumnToggledEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ColumnToggledEventArgs");
            a.item("__isPlainObject", "Boolean");
            a.item("Detail", "ExportedType:WebColumnToggledEventArgsDetail");
        }
        static d(a) {
            WebColumnToggledEventArgsDescriptionMetadata.b(a);
            a.aa("WebColumnToggledEventArgs", () => new WebColumnToggledEventArgsDescription());
            a.z("WebColumnToggledEventArgs", WebColumnToggledEventArgsDescriptionMetadata.a);
        }
    }
    WebColumnToggledEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebColumnToggledEventArgsDescriptionMetadata, 'WebColumnToggledEventArgsDescriptionMetadata');
    WebColumnToggledEventArgsDescriptionMetadata.a = null;
    return WebColumnToggledEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebColumnToggledEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnToggledEventArgsDetailDescriptionMetadata } from "./WebColumnToggledEventArgsDetailDescriptionMetadata";
import { WebColumnToggledEventArgsDescription } from "./WebColumnToggledEventArgsDescription";
/**
 * @hidden
 */
export let WebColumnToggledEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebColumnToggledEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebColumnToggledEventArgsDescriptionMetadata.a == null) {
                WebColumnToggledEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebColumnToggledEventArgsDescriptionMetadata.c(WebColumnToggledEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebColumnToggledEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebColumnToggledEventArgsDescriptionMetadata.a);
            WebColumnToggledEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ColumnToggledEventArgs");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Detail", "ExportedType:WebColumnToggledEventArgsDetail");
        }
        static d(a) {
            WebColumnToggledEventArgsDescriptionMetadata.b(a);
            a.ac("WebColumnToggledEventArgs", () => new WebColumnToggledEventArgsDescription());
            a.ab("WebColumnToggledEventArgs", WebColumnToggledEventArgsDescriptionMetadata.a);
        }
    }
    WebColumnToggledEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebColumnToggledEventArgsDescriptionMetadata, 'WebColumnToggledEventArgsDescriptionMetadata');
    WebColumnToggledEventArgsDescriptionMetadata.a = null;
    return WebColumnToggledEventArgsDescriptionMetadata;
})();
